%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MatNICEEGRecord
%
% This function connects to the COREGUI Remote Stimulation Server and 
% reads the EEG signal for t number of seconds. The server
% is running on the machine where the COREGUI application runs on the port
% 1234.
%
% Input:
% period     : number of seconds to read from the stream
% n_channels : number of channels to read from the host
% host       : host to be connected to
%
% Output:
% eeg: [n_channel x samples] matrix reading the EEG signal
%
% Author: Sergi Torrellas (sergi.torrellas@neuroelectrics.com)
% Company: Neuroelectrics
% Created: 05 Mar 2014
% Known issues: None
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function eeg = RAMReplayTCPRead(period, n_channel, parse_triggers, parse_timestamps, socket)

	% Initial parameters
	
	N    = n_channel;  % number of channels
	bps  = 4;          % bytes per sample
	Ns   = 10;         % number of samples to read in the buffer each time (between 20 and 250)
	buff = bps*Ns*N;   % Number of bytes to read in total for all channels
    if (parse_triggers)
        buff = buff+ 4*Ns;   % + trigger
    end
    if (parse_timestamps)
        buff = buff + 8*Ns;   % + timestamp
    end
	sps = 500;         %number of samples per second
	collectN = ceil(period*sps/Ns);         %number of biffers to attain collection time
    
    import java.net.Socket
	import java.io.*
	import java.nio.*
    
	ch = channels.Channels.newChannel(socket.getInputStream);
	bytes = ByteBuffer.allocate(buff);
	bytes.order(ByteOrder.BIG_ENDIAN);
    
    numcolumns=N;
    columnTriggers=0;
    columnTimestamps=0;

    if (parse_triggers)
        numcolumns = numcolumns + 1;
        columnTriggers=numcolumns;
    end
    
    if (parse_timestamps)
        numcolumns = numcolumns + 1;
        columnTimestamps=numcolumns;
    end

	eeg = zeros(N,collectN*Ns);

	n_bytes = 0;
	counter = 0;
	while 1
		n_bytes = n_bytes + ch.read(bytes);
		if n_bytes < buff
			continue;
		end
		n_bytes = 0;
		bytes.rewind;
		for k = 1 : Ns
			for j = 1 : N
				eeg(j,k+counter*Ns) = bytes.getInt;
            end
            if (parse_triggers)
                eeg(columnTriggers,k+counter*Ns) = bytes.getInt;
            end
            if (parse_timestamps)
                eeg(columnTimestamps,k+counter*Ns) = uint64(bytes.getLong);
            end    
		end
		counter = counter + 1;
		bytes.rewind;
		if counter == collectN
		   break 
		end
	end
	disp('Done.')

	eeg = eeg';

end